(($, Drupal, once) => {
  function _initCaptchaObserver(element) {
    const observer = new MutationObserver((mutations) => {
      mutations.forEach((mutation) => {
        mutation.addedNodes.forEach((addedNode) => {
          if (addedNode.id === 'frontal') {
            observer.disconnect();
            element.dispatchEvent(new Event('captcha-loaded'));
          }
        });
      });
    });
    observer.observe(element, { subtree: true, childList: true });
  }

  function _disableBlurOnLinks(captchaStyle) {
    ['ReloadLink', 'SoundLink'].forEach((linkSuffix) => {
      const linkId = `${captchaStyle}_${linkSuffix}`;
      const link = document.getElementById(linkId);
      link.blur = () => {};
    });
  }

  Drupal.behaviors.captchetat = {
    attach(context, settings) {
      once('captchetat', '#botdetect-captcha', context).forEach((element) => {
        $('#botdetect-captcha').captcha({
          captchaEndpoint: settings.captchetat.captchaEndpoint,
        });
        if (settings.captchetat.keepFocus) {
          _initCaptchaObserver(element);
          element.addEventListener('captcha-loaded', () => {
            // Disable blur method on captcha buttons for better accessibility.
            _disableBlurOnLinks(settings.captchetat.captchaStyle);
          });
        }
      });
    },
  };
})(jQuery, Drupal, once);
