<?php

namespace Drupal\captchetat\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Configure CaptchEtat settings for this site.
 */
class CaptchetatSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  const SETTINGS = 'captchetat.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'captchetat_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['api_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('API CaptchEtat Configuration'),
      '#weight' => 0,
      '#collapsible' => TRUE,
    ];
    $form['api_settings']['sandbox'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Sandbox mode'),
      '#default_value' => $config->get('sandbox') ?? TRUE,
    ];
    $form['api_settings']['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID'),
      '#default_value' => $config->get('client_id'),
      '#required' => TRUE,
    ];
    $form['api_settings']['client_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client Secret'),
      '#default_value' => $config->get('client_secret'),
      '#required' => TRUE,
    ];

    $form['captcha_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('CaptchEtat CAPTCHA Configuration'),
      '#weight' => 1,
      '#collapsible' => TRUE,
    ];
    $captcha_styles = [
      'captcha' => $this->t('6 to 9 alphanumeric characters'),
      'numerique6_7Captcha' => $this->t('6 to 7 numeric characters'),
      'alphabetique6_7Captcha' => $this->t('6 to 7 alphabetical characters'),
      'alphanumerique12Captcha' => $this->t('12 alphanumeric characters'),
      'alphabetique12Captcha' => $this->t('12 alphabetical characters'),
      'numerique12Captcha' => $this->t('12 numeric characters'),
      'alphanumerique4to6LightCaptcha' => $this->t('4 to 6 alphanumeric characters (light)'),
      'alphanumerique6to9LightCaptcha' => $this->t('6 to 9 alphanumeric characters (light)'),
    ];
    $form['captcha_settings']['captcha_style'] = [
      '#type' => 'select',
      '#title' => $this->t('CAPTCHA Style'),
      '#default_value' => $config->get('captcha_style') ?? 'captcha',
      '#options' => $captcha_styles,
      '#required' => TRUE,
    ];
    $form['captcha_settings']['keep_focus'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Keep focus on captcha buttons'),
      '#default_value' => $config->get('keep_focus') ?? TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('sandbox', $form_state->getValue('sandbox'))
      ->set('client_id', $form_state->getValue('client_id'))
      ->set('client_secret', $form_state->getValue('client_secret'))
      ->set('captcha_style', $form_state->getValue('captcha_style'))
      ->set('keep_focus', $form_state->getValue('keep_focus'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
