<?php

namespace Drupal\captchetat\Service;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Service for calling CaptchEtat APIs.
 */
interface CaptchetatServiceInterface {

  /**
   * Removes CaptchEtat API access token from Drupal cache.
   */
  public function clearApiToken(): void;

  /**
   * Fetches the CaptchEtat API access token.
   *
   * @return string
   *   The access token generated by the CaptchEtat API.
   */
  public function fetchApiToken(): string;

  /**
   * Returns the CaptchEtat API access token.
   *
   * @return string
   *   The access token provided by the CaptchEtat API.
   */
  public function getApiToken(): string;

  /**
   * Gets Captcha from Captchetat API.
   *
   * @param string $token
   *   CaptchEtat API access token.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current http request.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   HTTP Response for the CaptchEtat element.
   */
  public function getCaptcha(string $token, Request $request): Response;

  /**
   * Returns the CaptchEtat API status.
   *
   * @param string $token
   *   CaptchEtat API access token.
   *
   * @return mixed
   *   Returns the CaptchEtat status info or FALSE on failure.
   */
  public function healthCheck(string $token): mixed;

  /**
   * Checks the CaptchEtat service availability.
   *
   * @param string $token
   *   CaptchEtat API access token.
   *
   * @return bool
   *   Returns TRUE if the CaptchEtat service is UP, FALSE otherwise.
   */
  public function isServiceUp(string $token): bool;

  /**
   * Validates the user submission.
   *
   * @param string $captcha_id
   *   The captcha ID.
   * @param string $user_entered_captcha_code
   *   The user entered captcha code.
   * @param string $token
   *   CaptchEtat API access token.
   *
   * @return bool
   *   TRUE if validation successful, FALSE otherwise.
   */
  public function validateCaptcha(string $captcha_id, string $user_entered_captcha_code, string $token): bool;

}
